pub struct RepositoryFetcher;Implementations
Sourceimpl RepositoryFetcher
impl RepositoryFetcher
Sourcepub fn fetch_repository(
&self,
config: &RepositoryConfiguration,
cache_path: &str,
) -> Result<(), Cause<ErrorType>>
pub fn fetch_repository( &self, config: &RepositoryConfiguration, cache_path: &str, ) -> Result<(), Cause<ErrorType>>
Fetch a repository to a temporary directory This is a wrapper around the existing fetch functionality with caching logic