pub struct CacheKeyGenerator;Implementations
Sourceimpl CacheKeyGenerator
impl CacheKeyGenerator
Sourcepub fn generate_key(config: &RepositoryConfiguration) -> String
pub fn generate_key(config: &RepositoryConfiguration) -> String
Generate a unique cache key for a repository configuration The key is based on the repository URL and branch
Sourcepub fn generate_url_branch_key(url: &str, branch: &str) -> String
pub fn generate_url_branch_key(url: &str, branch: &str) -> String
Generate a cache key specifically for the URL and branch