pub struct CacheManager { /* private fields */ }Implementations
Sourceimpl CacheManager
impl CacheManager
pub fn new() -> Self
Sourcepub fn get_or_schedule_fetch(
&self,
config: &RepositoryConfiguration,
) -> Result<String, String>
pub fn get_or_schedule_fetch( &self, config: &RepositoryConfiguration, ) -> Result<String, String>
Determine if we need to fetch a repository, or if it’s already cached. Returns the cache path for the repository.
Sourcepub fn plan_fetch_operations(
&self,
configs: &[RepositoryConfiguration],
) -> Result<(Vec<RepositoryConfiguration>, Vec<WireOperation>), String>
pub fn plan_fetch_operations( &self, configs: &[RepositoryConfiguration], ) -> Result<(Vec<RepositoryConfiguration>, Vec<WireOperation>), String>
Process a list of repository configurations to determine the optimal fetching strategy. Identifies unique repositories based on URL, branch, and optional commit hash. Returns a list of unique configurations to fetch and corresponding wire operations.